class ArgumentNotFoundError(Exception):
    pass


class ChannelNotFoundError(Exception):
    pass


class UserNotFoundError(Exception):
    pass


class ReactionNotFoundError(Exception):
    pass


class KeywordArgumentNotFoundError(Exception):
    pass


class MessageNotFoundError(Exception):
    pass


class KeyValueError(Exception):
    pass
