# Generated by Django 2.0.2 on 2018-04-14 21:44

import django.contrib.postgres.fields.jsonb
from django.db import migrations
import foreignform.fields


class Migration(migrations.Migration):

    dependencies = [
        ('slackchat', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='channel',
            name='extras',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='chattype',
            name='jsonSchema',
            field=foreignform.fields.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='chattype',
            name='uiSchema',
            field=foreignform.fields.JSONField(blank=True, null=True),
        ),
    ]
